@@ -3,18 +3,18 @@
 #' @description
 #' This function generates subsets of a vector.
 #'
-#' @param v
-#' A \code{vector} (\code{numeric} or \code{character}).
+#' @param v \[atomic()`\]\cr
+#' A vector of elements.
 #'
-#' @param n
-#' An \code{integer} vector with the required subset sizes.
-#' By default, \code{n = seq_along(v)}, i.e., all subsets of \code{v} are
-#' generated.
+#' @param n \[integer(1)`\]\cr
+#' The requested subset sizes.
 #'
 #' @return
 #' A \code{list}, each element is a subset of \code{v}.
 #'
 #' @export
+#' @keywords indexing
+#' @family vector helpers
 #'
 #' @examples
 #' v <- 1:3
@@ -23,9 +23,15 @@
 #' subsets(integer())  # trivial case works
 
 subsets <- function(v, n = seq_along(v)) {
-  checkmate::assert_atomic_vector(v)
-  checkmate::assert_integerish(
-    n, lower = 1, upper = length(v), any.missing = FALSE, unique = TRUE
+  input_check_response(
+    check = checkmate::check_atomic_vector(v),
+    var_name = "v"
+  )
+  input_check_response(
+    check = checkmate::check_integerish(
+      n, lower = 1, upper = length(v), any.missing = FALSE, unique = TRUE
+    ),
+    var_name = "n"
   )
   if (length(v) == 0 || length(n) == 0) {
     return(list())
